@@ -13,7 +13,7 @@ Options:
   --host=<host>      TCP mode, connect to host instead of serial port.
   --repeat=<repeat>  How often to repeat a command [default: 1].
   -m=<handling>      How to handle incoming packets [default: event].
-  --ignore=<ignore>  List of device ids to ignore, end with * to match wildcard.
+  --ignore=<ignore>  List of device ids to ignore, wildcards supported.
   -h --help          Show this screen.
   -v                 Increase verbosity
   --version          Show version.
@@ -22,62 +22,68 @@ Options:
 import asyncio
 import logging
 import sys
+from typing import Dict, Optional, Sequence, Type  # noqa: unused-import
 
 import pkg_resources
 from docopt import docopt
 
-from .protocol import (
+from .protocol import (  # noqa: unused-import
+    CommandSerialization,
     EventHandling,
     InverterProtocol,
     PacketHandling,
+    ProtocolBase,
     RepeaterProtocol,
     RflinkProtocol,
-    create_rflink_connection
+    create_rflink_connection,
 )
 
 PROTOCOLS = {
-    'command': RflinkProtocol,
-    'event': EventHandling,
-    'print': PacketHandling,
-    'invert': InverterProtocol,
-    'repeat': RepeaterProtocol,
-}
+    "command": RflinkProtocol,
+    "event": EventHandling,
+    "print": PacketHandling,
+    "invert": InverterProtocol,
+    "repeat": RepeaterProtocol,
+}  # type: Dict[str, Type[ProtocolBase]]
 
-ALL_COMMANDS = ['on', 'off', 'allon', 'alloff', 'up', 'down', 'stop', 'pair']
+ALL_COMMANDS = ["on", "off", "allon", "alloff", "up", "down", "stop", "pair"]
 
 
-def main(argv=sys.argv[1:], loop=None):
+def main(
+    argv: Sequence[str] = sys.argv[1:], loop: Optional[asyncio.AbstractEventLoop] = None
+) -> None:
     """Parse argument and setup main program loop."""
-    args = docopt(__doc__, argv=argv,
-                  version=pkg_resources.require('rflink')[0].version)
+    args = docopt(
+        __doc__, argv=argv, version=pkg_resources.require("rflink")[0].version
+    )
 
     level = logging.ERROR
-    if args['-v']:
+    if args["-v"]:
         level = logging.INFO
-    if args['-v'] == 2:
+    if args["-v"] == 2:
         level = logging.DEBUG
     logging.basicConfig(level=level)
 
     if not loop:
         loop = asyncio.get_event_loop()
 
-    if args['--ignore']:
-        ignore = args['--ignore'].split(',')
+    if args["--ignore"]:
+        ignore = args["--ignore"].split(",")
     else:
         ignore = []
 
     command = next((c for c in ALL_COMMANDS if args[c] is True), None)
 
     if command:
-        protocol = PROTOCOLS['command']
+        protocol_type = PROTOCOLS["command"]
     else:
-        protocol = PROTOCOLS[args['-m']]
+        protocol_type = PROTOCOLS[args["-m"]]
 
     conn = create_rflink_connection(
-        protocol=protocol,
-        host=args['--host'],
-        port=args['--port'],
-        baud=args['--baud'],
+        protocol=protocol_type,
+        host=args["--host"],
+        port=args["--port"],
+        baud=args["--baud"],
         loop=loop,
         ignore=ignore,
     )
@@ -86,10 +92,11 @@ def main(argv=sys.argv[1:], loop=None):
 
     try:
         if command:
-            for _ in range(int(args['--repeat'])):
+            assert isinstance(protocol, CommandSerialization)
+            for _ in range(int(args["--repeat"])):
                 loop.run_until_complete(
-                    protocol.send_command_ack(
-                        args['<id>'], command))
+                    protocol.send_command_ack(args["<id>"], command)
+                )
         else:
             loop.run_forever()
     except KeyboardInterrupt:
