@@ -3,11 +3,14 @@
 # ./.homeassistant/deps/lib/python/site-packages/rflink/parser.py
 # /Library/Frameworks/Python.framework/Versions/3.6//lib/python3.6/site-packages/rflink/parser.py
 
+import logging
 import re
 import time
 from enum import Enum
 from typing import Any, Callable, DefaultDict, Dict, Generator, cast
 
+log = logging.getLogger(__name__)
+
 UNKNOWN = "unknown"
 SWITCH_COMMAND_TEMPLATE = "{node};{protocol};{id};{switch};{command};"
 PACKET_ID_SEP = "_"
@@ -22,6 +25,7 @@ VALUE = "[0-9a-zA-Z]+"
 COMMAND = "[0-9a-zA-Z]+"
 CONTROL_COMMAND = "[A-Z]+(=[A-Z0-9]+)?"
 DATA = "[a-zA-Z0-9;=_]+"
+DEBUG_DATA_RTS = "[a-zA-Z0-9;=_ ]+"
 DEBUG_DATA = "[a-zA-Z0-9,;=_()]+"
 RESPONSES = "OK"
 VERSION = r"[0-9a-zA-Z \.-]+"
@@ -60,6 +64,12 @@ PACKET_RFUDEBUGF = DELIM.join(["20", SEQUENCE, "RFUDEBUG=OFF"])
 PACKET_QRFDEBUGN = DELIM.join(["20", SEQUENCE, "QRFDEBUG=ON"])
 PACKET_QRFDEBUGF = DELIM.join(["20", SEQUENCE, "QRFDEBUG=OFF"])
 
+PACKET_GPIOON = DELIM.join(["20", SEQUENCE, "setGPIO=ON"])
+PACKET_GPIOOFF = DELIM.join(["20", SEQUENCE, "setGPIO=OFF"])
+
+# 20;84;Debug;RTS P1;a63f33003cf000665a5a;
+PACKET_DEBUGRTS = DELIM.join(["20", SEQUENCE, "Debug", DEBUG_DATA_RTS])
+
 # 11;20;0B;NewKaku;ID=000005;SWITCH=2;CMD=ON;
 PACKET_DEVICE_CREATE = "11;" + PACKET_DEVICE
 
@@ -84,6 +94,9 @@ PACKET_HEADER_RE = (
             PACKET_RFUDEBUGF,
             PACKET_QRFDEBUGN,
             PACKET_QRFDEBUGF,
+            PACKET_GPIOOFF,
+            PACKET_GPIOON,
+            PACKET_DEBUGRTS,
         ]
     )
     + ");$"
@@ -282,9 +295,12 @@ def decode_packet(packet: str) -> PacketType:
         data["ping"] = protocol.lower()
 
     # debug response
-    elif protocol == "DEBUG":
+    elif protocol.lower() == "debug":
         data["protocol"] = protocol.lower()
-        data["tm"] = packet[3:5]
+        if attrs.startswith("RTS P1"):
+            data["rts_p1"] = attrs.strip(DELIM).split(DELIM)[1]
+        else:
+            data["tm"] = packet[3:5]
 
     # failure response
     elif protocol == "CMD UNKNOWN":
@@ -305,9 +321,20 @@ def decode_packet(packet: str) -> PacketType:
 
     # convert key=value pairs where needed
     for attr in filter(None, attrs.strip(DELIM).split(DELIM)):
+        if "=" not in attr:
+            continue
         key, value = attr.lower().split("=", 1)
         if key in VALUE_TRANSLATION:
-            value = VALUE_TRANSLATION[key](value)
+            try:
+                value = VALUE_TRANSLATION[key](value)
+            except ValueError:
+                log.warning(
+                    "Could not convert attr '%s' value '%s' to expected type '%s'",
+                    key,
+                    value,
+                    VALUE_TRANSLATION[key].__name__,
+                )
+                continue
         name = PACKET_FIELDS.get(key, key)
         data[name] = value
         unit = UNITS.get(key, None)
